Python 常用方法
~~~~~~~~~~~~~~~

-  regex_utils 正则相关

::

   is_mobile_simple        : 简单判断是否为手机号
   is_email                : 判断是否邮箱
   is_url                  ：判断是否为url
   is_ip                   : 判断是否为ip
   is_zh                   : 判断是否为中文
   is_chain_postal_code    ：判断是否为中国邮编

-  encrypt_utils 加密相关

::

   md5                     ：获取md5
